MERGE INTO FLEET.RAW_FLEET T USING(
  SELECT
    STRM.RECORD_CONTENT:"op" :: VARCHAR AS OP,
    COALESCE(
      STRM.RECORD_CONTENT:"before"."pid" :: INTEGER,
      STRM.RECORD_CONTENT:"after"."pid" :: INTEGER
    ) AS PID,
    STRM.RECORD_CONTENT:"after"."fleet_id" :: VARCHAR AS FLEET_ID,
    STRM.RECORD_CONTENT:"after"."name" :: VARCHAR AS NAME,
    STRM.RECORD_CONTENT:"after"."company_id" :: VARCHAR AS COMPANY_ID,
    STRM.RECORD_CONTENT:"after"."created_at" :: BIGINT AS CREATED_AT,
    STRM.RECORD_CONTENT:"after"."updated_at" :: BIGINT AS UPDATED_AT
  FROM
    CDC.STRM_FLEET__FLEET STRM
  WHERE
    STRM.RECORD_CONTENT:"op" :: VARCHAR IN ('r', 'u', 'c', 'd')
    AND COALESCE(
      STRM.RECORD_CONTENT:"before":"pid",
      STRM.RECORD_CONTENT:"after":"pid"
    ) IS NOT NULL QUALIFY ROW_NUMBER() OVER (
      COALESCE(
        STRM.RECORD_CONTENT:"before":"pid",
        STRM.RECORD_CONTENT:"after":"pid"
      ),
      ORDER BY
        (
          STRM.RECORD_CONTENT:"ts_ms" :: INTEGER * 100000000000000 + STRM.RECORD_CONTENT:"source"."pos" :: INTEGER
        )
    ) = 1
) S ON T.PID = S.PID
WHEN MATCHED
AND OP = 'd' THEN DELETE
WHEN MATCHED
AND (
  OP = 'u'
  OR OP = 'c'
) THEN
UPDATE
SET
  T.FLEET_ID = S.FLEET_ID,
  T.NAME = S.NAME,
  T.COMPANY_ID = S.COMPANY_ID,
  T.CREATED_AT = S.CREATED_AT,
  T.UPDATED_AT = S.UPDATED_AT,
  T.PID = S.PID
  WHEN NOT MATCHED
  AND (OP != 'd') THEN
INSERT
  (
    FLEET_ID,
    NAME,
    COMPANY_ID,
    CREATED_AT,
    UPDATED_AT,
    PID
  )
VALUES
  (
    S.FLEET_ID,
    S.NAME,
    S.COMPANY_ID,
    S.CREATED_AT,
    S.UPDATED_AT,
    S.PID
  );